@@ -59,6 +59,13 @@ from shodan.cli.scan import scan
 
 # Make "-h" work like "--help"
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
+CONVERTERS = {
+    'kml': KmlConverter,
+    'csv': CsvConverter,
+    'geo.json': GeoJsonConverter,
+    'images': ImagesConverter,
+    'xlsx': ExcelConverter,
+}
 
 # Define a basestring type if necessary for Python3 compatibility
 try:
@@ -66,6 +73,7 @@ try:
 except NameError:
     basestring = str
 
+
 # Define the main entry point for all of our commands
 # and expose a way for 3rd-party plugins to tie into the Shodan CLI.
 @with_plugins(iter_entry_points('shodan.cli.plugins'))
@@ -81,13 +89,6 @@ main.add_command(org)
 main.add_command(scan)
 
 
-CONVERTERS = {
-    'kml': KmlConverter,
-    'csv': CsvConverter,
-    'geo.json': GeoJsonConverter,
-    'images': ImagesConverter,
-    'xlsx': ExcelConverter,
-}
 @main.command()
 @click.option('--fields', help='List of properties to output.', default=None)
 @click.argument('input', metavar='<input file>')
@@ -209,7 +210,7 @@ def init(key):
     shodan_dir = os.path.expanduser(SHODAN_CONFIG_DIR)
     if not os.path.isdir(shodan_dir):
         try:
-            os.mkdir(shodan_dir)
+            os.makedirs(shodan_dir)
         except OSError:
             raise click.ClickException('Unable to create directory to store the Shodan API key ({})'.format(shodan_dir))
 
@@ -255,10 +256,9 @@ def count(query):
 
 @main.command()
 @click.option('--limit', help='The number of results you want to download. -1 to download all the data possible.', default=1000, type=int)
-@click.option('--skip', help='The number of results to skip when starting the download.', default=0, type=int)
 @click.argument('filename', metavar='<filename>')
 @click.argument('query', metavar='<search query>', nargs=-1)
-def download(limit, skip, filename, query):
+def download(limit, filename, query):
     """Download search results and save them in a compressed JSON file."""
     key = get_api_key()
 
@@ -298,15 +298,11 @@ def download(limit, skip, filename, query):
     # A limit of -1 means that we should download all the data
     if limit <= 0:
         limit = total
-    
-        # Adjust the total number of results we should expect to download if the user is skipping results
-        if skip > 0:
-            limit -= skip
 
     with helpers.open_file(filename, 'w') as fout:
         count = 0
         try:
-            cursor = api.search_cursor(query, minify=False, skip=skip)
+            cursor = api.search_cursor(query, minify=False)
             with click.progressbar(cursor, length=limit) as bar:
                 for banner in bar:
                     helpers.write_banner(fout, banner)
